types

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 8, 2016 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Event

type Event struct {
	Name   string
	Task   string
	Time   time.Time
	Extras map[string]interface{}
}

func NewEndEvent

func NewEndEvent(taskName string, statusCode int, startTime time.Time) *Event

func NewOutputEvent

func NewOutputEvent(taskName string, body []byte) *Event

func NewStartEvent

func NewStartEvent(taskName string) *Event

type Task

type Task struct {
	Name        string
	Description string
	Time        bool
	Run         string
	Executor    string
	Pre         []string
	Post        []string
	Env         []string
	Workdir     string
}

Task is a representation of a dogfile task

type TaskMap

type TaskMap map[string]*Task

TaskMap is a map in which the key is a task name and the value is a Task object

Jump to